# Frames Module

The `wandas.frames` module provides various data frame classes for manipulating and representing audio data.

## ChannelFrame

ChannelFrame is the basic frame for handling time-domain waveform data.

::: wandas.frames.channel.ChannelFrame

## SpectralFrame

SpectralFrame is a frame for handling frequency-domain data.

::: wandas.frames.spectral.SpectralFrame

## SpectrogramFrame

SpectrogramFrame is a frame for handling time-frequency domain (spectrogram) data.

::: wandas.frames.spectrogram.SpectrogramFrame

## NOctFrame

NOctFrame is a frame class for octave-band analysis.

::: wandas.frames.noct.NOctFrame

## Mixins

Mixins for extending frame functionality.

### ChannelProcessingMixin

::: wandas.frames.mixins.channel_processing_mixin.ChannelProcessingMixin

### ChannelTransformMixin

::: wandas.frames.mixins.channel_transform_mixin.ChannelTransformMixin
